EvaluationLoopTrainingCallback
==============================

.. currentmodule:: pykeen.training.callbacks

.. autoclass:: EvaluationLoopTrainingCallback
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~EvaluationLoopTrainingCallback.evaluation_loop

   .. rubric:: Methods Summary

   .. autosummary::

      ~EvaluationLoopTrainingCallback.post_epoch

   .. rubric:: Attributes Documentation

   .. autoattribute:: evaluation_loop

   .. rubric:: Methods Documentation

   .. automethod:: post_epoch
